..

=====================================================
Deploying an OVN Development Environment with vagrant
=====================================================


The vagrant directory contains a set of vagrant configurations which will
help you deploy Neutron with the OVN driver for testing or development purposes.

We provide a sparse multinode architecture with clear separation between
services. In the future we will include all-in-one and multi-gateway
architectures.


.. toctree::
   :maxdepth: 2

   prerequisites
   sparse-architecture
